@@ -1,9 +1,12 @@
 // Since users can pick and choose protocols, we need all of these to be public.
 pub mod aneros;
+pub mod ankni;
 pub mod cachito;
 pub mod fleshlight_launch_helper;
 pub mod fredorch;
 pub mod generic_command_manager;
+pub mod hgod;
+pub mod htk_bm;
 pub mod jejoue;
 pub mod kiiroo_v2;
 pub mod kiiroo_v21;
@@ -13,6 +16,7 @@ pub mod lelof1s;
 pub mod libo_elle;
 pub mod libo_shark;
 pub mod libo_vibes;
+pub mod lovedistance;
 pub mod lovehoney_desire;
 pub mod lovense;
 pub mod lovense_connect_service;
@@ -20,6 +24,7 @@ pub mod lovenuts;
 pub mod magic_motion_v1;
 pub mod magic_motion_v2;
 pub mod magic_motion_v3;
+pub mod mannuo;
 pub mod maxpro;
 pub mod mizzzee;
 pub mod motorbunny;
@@ -30,7 +35,11 @@ pub mod picobong;
 pub mod prettylove;
 pub mod raw_protocol;
 pub mod realov;
+pub mod satisfyer;
 pub mod svakom;
+pub mod svakom_alex;
+pub mod svakom_iker;
+pub mod svakom_sam;
 pub mod tcode_v03;
 pub mod thehandy;
 pub mod vibratissimo;
@@ -47,12 +56,21 @@ use crate::{
   core::{
     errors::{ButtplugDeviceError, ButtplugError},
     messages::{
-      self, ButtplugDeviceCommandMessageUnion, ButtplugDeviceMessage, ButtplugDeviceMessageType,
-      ButtplugMessage, DeviceMessageAttributesMap, RawReading, VibrateCmd, VibrateSubcommand,
+      self,
+      ButtplugDeviceCommandMessageUnion,
+      ButtplugDeviceMessage,
+      ButtplugDeviceMessageType,
+      ButtplugMessage,
+      DeviceMessageAttributesMap,
+      RawReading,
+      VibrateCmd,
+      VibrateSubcommand,
     },
   },
   device::{
-    configuration_manager::DeviceProtocolConfiguration, ButtplugDeviceResultFuture, DeviceReadCmd,
+    configuration_manager::DeviceProtocolConfiguration,
+    ButtplugDeviceResultFuture,
+    DeviceReadCmd,
     Endpoint,
   },
 };
@@ -79,8 +97,11 @@ where
 pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   let map = DashMap::new();
   add_to_protocol_map::<aneros::Aneros>(&map, "aneros");
+  add_to_protocol_map::<ankni::Ankni>(&map, "ankni");
   add_to_protocol_map::<cachito::Cachito>(&map, "cachito");
   add_to_protocol_map::<fredorch::Fredorch>(&map, "fredorch");
+  add_to_protocol_map::<hgod::Hgod>(&map, "hgod");
+  add_to_protocol_map::<htk_bm::HtkBm>(&map, "htk_bm");
   add_to_protocol_map::<jejoue::JeJoue>(&map, "jejoue");
   add_to_protocol_map::<kiiroo_v2::KiirooV2>(&map, "kiiroo-v2");
   add_to_protocol_map::<kiiroo_v2_vibrator::KiirooV2Vibrator>(&map, "kiiroo-v2-vibrator");
@@ -94,6 +115,7 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   add_to_protocol_map::<libo_shark::LiboShark>(&map, "libo-shark");
   add_to_protocol_map::<libo_vibes::LiboVibes>(&map, "libo-vibes");
   add_to_protocol_map::<lovehoney_desire::LovehoneyDesire>(&map, "lovehoney-desire");
+  add_to_protocol_map::<lovedistance::LoveDistance>(&map, "lovedistance");
   add_to_protocol_map::<lovense::Lovense>(&map, "lovense");
   add_to_protocol_map::<lovense_connect_service::LovenseConnectService>(
     &map,
@@ -103,6 +125,7 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   add_to_protocol_map::<magic_motion_v1::MagicMotionV1>(&map, "magic-motion-1");
   add_to_protocol_map::<magic_motion_v2::MagicMotionV2>(&map, "magic-motion-2");
   add_to_protocol_map::<magic_motion_v3::MagicMotionV3>(&map, "magic-motion-3");
+  add_to_protocol_map::<mannuo::ManNuo>(&map, "mannuo");
   add_to_protocol_map::<maxpro::Maxpro>(&map, "maxpro");
   add_to_protocol_map::<mizzzee::MizzZee>(&map, "mizzzee");
   add_to_protocol_map::<motorbunny::Motorbunny>(&map, "motorbunny");
@@ -113,7 +136,11 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   add_to_protocol_map::<prettylove::PrettyLove>(&map, "prettylove");
   add_to_protocol_map::<raw_protocol::RawProtocol>(&map, "raw");
   add_to_protocol_map::<realov::Realov>(&map, "realov");
+  add_to_protocol_map::<satisfyer::Satisfyer>(&map, "satisfyer");
   add_to_protocol_map::<svakom::Svakom>(&map, "svakom");
+  add_to_protocol_map::<svakom_alex::SvakomAlex>(&map, "svakom-alex");
+  add_to_protocol_map::<svakom_iker::SvakomIker>(&map, "svakom-iker");
+  add_to_protocol_map::<svakom_sam::SvakomSam>(&map, "svakom-sam");
   add_to_protocol_map::<tcode_v03::TCodeV03>(&map, "tcode-v03");
   add_to_protocol_map::<thehandy::TheHandy>(&map, "thehandy");
   add_to_protocol_map::<vibratissimo::Vibratissimo>(&map, "vibratissimo");
@@ -144,7 +171,10 @@ pub trait ButtplugProtocol: ButtplugProtocolCommandHandler + Sync {
         Err(err) => return Err(err),
       };
       let (names, attrs) = config.get_attributes(&device_identifier, &endpoints)?;
-      let name = names.get("en-us").unwrap().clone();
+      let name = names
+        .get("en-us")
+        .expect("Required value for JSON Schema")
+        .clone();
       Ok(Self::new_protocol(&name, attrs))
     })
   }
