@@ -9,8 +9,7 @@
 #![crate_name = "buttplug"]
 // Required for select! expansion in RemoteServer
 #![recursion_limit = "512"]
-#![cfg_attr(feature = "unstable", feature(external_doc))]
-#![cfg_attr(feature = "unstable", doc(include = "../README.md"))]
+#![doc = include_str!("../README.md")]
 
 #[macro_use]
 extern crate buttplug_derive;
