@@ -6,20 +6,28 @@ use crate::{
   },
   device::{
     configuration_manager::{BluetoothLESpecifier, DeviceSpecifier, ProtocolDefinition},
-    ButtplugDeviceEvent, ButtplugDeviceImplCreator, DeviceImpl, DeviceImplInternal, DeviceReadCmd,
-    DeviceSubscribeCmd, DeviceUnsubscribeCmd, DeviceWriteCmd, Endpoint,
+    ButtplugDeviceEvent,
+    ButtplugDeviceImplCreator,
+    DeviceImpl,
+    DeviceImplInternal,
+    DeviceReadCmd,
+    DeviceSubscribeCmd,
+    DeviceUnsubscribeCmd,
+    DeviceWriteCmd,
+    Endpoint,
   },
   server::comm_managers::ButtplugDeviceSpecificError,
   util::async_manager,
 };
 use async_trait::async_trait;
 use btleplug::{
-  api::{BDAddr, Central, CentralEvent, Characteristic, Peripheral, ValueNotification, WriteType},
-  platform::Adapter,
+  api::{Central, CentralEvent, Characteristic, Peripheral, ValueNotification, WriteType},
+  platform::{Adapter, PeripheralId},
 };
 use futures::{
   future::{self, BoxFuture, FutureExt},
-  Stream, StreamExt,
+  Stream,
+  StreamExt,
 };
 use std::{
   collections::HashMap,
@@ -35,16 +43,24 @@ use uuid::Uuid;
 
 pub struct BtlePlugDeviceImplCreator<T: Peripheral + 'static> {
   name: String,
-  address: BDAddr,
+  address: PeripheralId,
+  services: Vec<Uuid>,
   device: T,
   adapter: Adapter,
 }
 
 impl<T: Peripheral> BtlePlugDeviceImplCreator<T> {
-  pub fn new(name: &str, address: &BDAddr, device: T, adapter: Adapter) -> Self {
+  pub fn new(
+    name: &str,
+    address: &PeripheralId,
+    services: &[Uuid],
+    device: T,
+    adapter: Adapter,
+  ) -> Self {
     Self {
       name: name.to_owned(),
       address: address.to_owned(),
+      services: services.to_vec(),
       device,
       adapter,
     }
@@ -60,25 +76,29 @@ impl<T: Peripheral> Debug for BtlePlugDeviceImplCreator<T> {
 #[async_trait]
 impl<T: Peripheral> ButtplugDeviceImplCreator for BtlePlugDeviceImplCreator<T> {
   fn get_specifier(&self) -> DeviceSpecifier {
-    DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device(&self.name))
+    DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device(
+      &self.name,
+      &self.services,
+    ))
   }
 
   async fn try_create_device_impl(
     &mut self,
     protocol: ProtocolDefinition,
   ) -> Result<DeviceImpl, ButtplugError> {
-    if let Err(err) = self.device.connect().await {
-      let return_err = ButtplugDeviceError::DeviceSpecificError(
-        ButtplugDeviceSpecificError::BtleplugError(format!("{:?}", err)),
-      );
-      return Err(return_err.into());
-    }
-    // Map UUIDs to endpoints
-    let mut uuid_map = HashMap::<Uuid, Endpoint>::new();
-    let mut endpoints = HashMap::<Endpoint, Characteristic>::new();
-    let chars = match self.device.discover_characteristics().await {
-      Ok(chars) => chars,
-      Err(err) => {
+    if !self
+      .device
+      .is_connected()
+      .await
+      .expect("If we crash here it's Bluez's fault. Use something else please.")
+    {
+      if let Err(err) = self.device.connect().await {
+        let return_err = ButtplugDeviceError::DeviceSpecificError(
+          ButtplugDeviceSpecificError::BtleplugError(format!("{:?}", err)),
+        );
+        return Err(return_err.into());
+      }
+      if let Err(err) = self.device.discover_services().await {
         error!("BTLEPlug error discovering characteristics: {:?}", err);
         return Err(
           ButtplugDeviceError::DeviceConnectionError(format!(
@@ -88,29 +108,60 @@ impl<T: Peripheral> ButtplugDeviceImplCreator for BtlePlugDeviceImplCreator<T> {
           .into(),
         );
       }
-    };
-    for proto_service in protocol.btle.unwrap().services.values() {
-      for (chr_name, chr_uuid) in proto_service.iter() {
-        let maybe_chr = chars.iter().find(|c| c.uuid == *chr_uuid);
-        if let Some(chr) = maybe_chr {
-          endpoints.insert(*chr_name, chr.clone());
-          uuid_map.insert(*chr_uuid, *chr_name);
+    }
+    // Map UUIDs to endpoints
+    let mut uuid_map = HashMap::<Uuid, Endpoint>::new();
+    let mut endpoints = HashMap::<Endpoint, Characteristic>::new();
+
+    for (proto_uuid, proto_service) in protocol
+      .btle
+      .expect("To get this far we are guaranteed to have a btle block in the config")
+      .services
+    {
+      for service in self.device.services() {
+        if service.uuid != proto_uuid {
+          continue;
+        }
+
+        debug!("Found required service {} {:?}", service.uuid, service);
+        for (chr_name, chr_uuid) in proto_service.iter() {
+          if let Some(chr) = service.characteristics.iter().find(|c| c.uuid == *chr_uuid) {
+            debug!(
+              "Found characteristic {} for endpoint {}",
+              chr.uuid, *chr_name
+            );
+            endpoints.insert(*chr_name, chr.clone());
+            uuid_map.insert(*chr_uuid, *chr_name);
+          } else {
+            error!(
+              "Characteristic {} ({}) not found, may cause issues in connection.",
+              chr_name, chr_uuid
+            );
+          }
         }
       }
     }
-    let notification_stream = self.device.notifications().await.unwrap();
+    let notification_stream = self
+      .device
+      .notifications()
+      .await
+      .expect("Should always be able to get notifications");
     let device_internal_impl = BtlePlugDeviceImpl::new(
       self.device.clone(),
       &self.name,
-      self.address,
-      self.adapter.events().await.unwrap(),
+      self.address.clone(),
+      self
+        .adapter
+        .events()
+        .await
+        .expect("Should always be able to get events"),
       notification_stream,
       endpoints.clone(),
       uuid_map,
     );
     let device_impl = DeviceImpl::new(
       &self.name,
-      &self.address.to_string(),
+      &format!("{:?}", self.address),
       &endpoints.keys().cloned().collect::<Vec<Endpoint>>(),
       Box::new(device_internal_impl),
     );
@@ -125,14 +176,16 @@ pub struct BtlePlugDeviceImpl<T: Peripheral + 'static> {
   endpoints: HashMap<Endpoint, Characteristic>,
 }
 
-unsafe impl<T: Peripheral + 'static> Send for BtlePlugDeviceImpl<T> {}
-unsafe impl<T: Peripheral + 'static> Sync for BtlePlugDeviceImpl<T> {}
+unsafe impl<T: Peripheral + 'static> Send for BtlePlugDeviceImpl<T> {
+}
+unsafe impl<T: Peripheral + 'static> Sync for BtlePlugDeviceImpl<T> {
+}
 
 impl<T: Peripheral + 'static> BtlePlugDeviceImpl<T> {
   pub fn new(
     device: T,
     name: &str,
-    address: BDAddr,
+    address: PeripheralId,
     mut adapter_event_stream: Pin<Box<dyn Stream<Item = CentralEvent> + Send>>,
     mut notification_stream: Pin<Box<dyn Stream<Item = ValueNotification> + Send>>,
     endpoints: HashMap<Endpoint, Characteristic>,
@@ -140,7 +193,7 @@ impl<T: Peripheral + 'static> BtlePlugDeviceImpl<T> {
   ) -> Self {
     let (event_stream, _) = broadcast::channel(256);
     let event_stream_clone = event_stream.clone();
-    let address_clone = address;
+    let address_clone = address.clone();
     let name_clone = name.to_owned();
     async_manager::spawn(async move {
       let mut error_notification = false;
@@ -161,8 +214,11 @@ impl<T: Peripheral + 'static> BtlePlugDeviceImpl<T> {
                 }
                 continue;
               };
+              if event_stream_clone.receiver_count() == 0 {
+                continue;
+              }
               if let Err(err) = event_stream_clone.send(ButtplugDeviceEvent::Notification(
-                address.to_string(),
+                format!("{:?}", address),
                 endpoint,
                 notification.value,
               )) {
@@ -170,7 +226,7 @@ impl<T: Peripheral + 'static> BtlePlugDeviceImpl<T> {
                   "Cannot send notification, device object disappeared: {:?}",
                   err
                 );
-                return;
+                break;
               }
             }
           }
@@ -181,18 +237,30 @@ impl<T: Peripheral + 'static> BtlePlugDeviceImpl<T> {
                   "Device {:?} disconnected",
                   name_clone
                 );
-                event_stream_clone
+                if event_stream_clone.receiver_count() != 0 {
+                  if let Err(err) = event_stream_clone
                   .send(ButtplugDeviceEvent::Removed(
-                    address_clone.to_string()
-                  ))
-                  .unwrap();
+                    format!("{:?}", address)
+                  )) {
+                    error!(
+                      "Cannot send notification, device object disappeared: {:?}",
+                      err
+                    );
+                  }
+                }
+                // At this point, we have nothing left to do because we can't reconnect a device
+                // that's been connected. Exit.
+                break;
               }
             }
           }
         }
       }
-    })
-    .unwrap();
+      info!(
+        "Exiting btleplug notification/event loop for device {:?}",
+        address_clone
+      )
+    });
     Self {
       device,
       endpoints,
@@ -235,11 +303,18 @@ impl<T: Peripheral + 'static> DeviceImplInternal for BtlePlugDeviceImpl<T> {
       WriteType::WithoutResponse
     };
     Box::pin(async move {
-      device
-        .write(&characteristic, &msg.data, write_type)
-        .await
-        .unwrap();
-      Ok(())
+      match device.write(&characteristic, &msg.data, write_type).await {
+        Ok(()) => Ok(()),
+        Err(err) => {
+          error!("BTLEPlug device write error: {:?}", err);
+          Err(
+            ButtplugDeviceError::DeviceSpecificError(ButtplugDeviceSpecificError::BtleplugError(
+              format!("{:?}", err),
+            ))
+            .into(),
+          )
+        }
+      }
     })
   }
 
