@@ -2,13 +2,16 @@ use super::lovense_connect_service_device_impl::LovenseServiceDeviceImplCreator;
 use crate::{
   core::ButtplugResultFuture,
   server::comm_managers::{
-    DeviceCommunicationEvent, DeviceCommunicationManager, DeviceCommunicationManagerBuilder,
+    DeviceCommunicationEvent,
+    DeviceCommunicationManager,
+    DeviceCommunicationManagerBuilder,
   },
   util::async_manager,
 };
 use dashmap::DashMap;
 use futures::future;
 use futures_timer::Delay;
+use reqwest::StatusCode;
 use serde::Deserialize;
 use serde_aux::prelude::*;
 use std::{
@@ -30,10 +33,14 @@ const LOVENSE_REMOTE_SERVICE_CHECK_INTERVAL: u64 = 1;
 pub(super) struct LovenseServiceToyInfo {
   pub id: String,
   pub name: String,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   #[serde(rename = "nickName")]
   pub nickname: String,
   #[serde(rename = "status", deserialize_with = "deserialize_bool_from_anything")]
   pub connected: bool,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   pub version: String,
   #[serde(deserialize_with = "deserialize_number_from_string")]
   pub battery: i8,
@@ -41,22 +48,36 @@ pub(super) struct LovenseServiceToyInfo {
 
 #[derive(Deserialize, Debug)]
 struct LovenseServiceHostInfo {
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   pub domain: String,
   #[serde(rename = "httpPort")]
   pub http_port: u16,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   #[serde(rename = "wsPort")]
   pub ws_port: u16,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   #[serde(rename = "httpsPort")]
   pub https_port: u16,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   #[serde(rename = "wssPort")]
   pub wss_port: u16,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   pub toys: HashMap<String, LovenseServiceToyInfo>,
 }
 
 #[derive(Deserialize, Debug)]
 struct LovenseServiceLocalInfo {
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   #[serde(rename = "type", deserialize_with = "deserialize_string_from_number")]
   pub reply_type: String,
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   #[serde(deserialize_with = "deserialize_number_from_string")]
   pub code: u32,
   pub data: HashMap<String, LovenseServiceToyInfo>,
@@ -79,8 +100,21 @@ async fn lovense_local_service_check(
     for host in hosts {
       match reqwest::get(format!("{}/GetToys", host)).await {
         Ok(res) => {
-          let text = res.text().await.unwrap();
-          let info: LovenseServiceLocalInfo = serde_json::from_str(&text).unwrap();
+          if res.status() != StatusCode::OK {
+            error!(
+              "Error contacting Lovense Connect Local API endpoint. Status returned: {}",
+              res.status()
+            );
+            tokio::time::sleep(Duration::from_secs(1)).await;
+            continue;
+          }
+
+          let text = res
+            .text()
+            .await
+            .expect("If we got a 200 back, we should at least have text.");
+          let info: LovenseServiceLocalInfo = serde_json::from_str(&text)
+            .expect("Should always get json back from service, if we got a response.");
 
           // First off, remove all devices that are no longer in the list
           // (devices turned off or removed from the Lovense Connect app)
@@ -94,13 +128,12 @@ async fn lovense_local_service_check(
           connected_device_info.retain(|k, _| info.data.contains_key(k));
 
           for (_, toy) in info.data.iter() {
-            if connected_device_info.contains_key(&toy.id) {
+            if let Some(info_ref) = connected_device_info.get(&toy.id) {
               // For some reason, this requires its own scoping block, otherwise
               // the write lock will hold forever, which blocks the server? I'm
               // guessing this has to do with loop hoisting but it still seems
               // odd.
               {
-                let info_ref = connected_device_info.get(&toy.id).unwrap();
                 let mut info_lock = info_ref.write().await;
                 *info_lock = toy.clone();
               }
@@ -120,7 +153,10 @@ async fn lovense_local_service_check(
             connected_device_info.insert(toy.id.clone(), Arc::new(RwLock::new((*toy).clone())));
             let device_creator = Box::new(LovenseServiceDeviceImplCreator::new(
               &host,
-              connected_device_info.get(&toy.id).unwrap().clone(),
+              connected_device_info
+                .get(&toy.id)
+                .expect("Just inserted this.")
+                .clone(),
             ));
             if event_sender
               .send(DeviceCommunicationEvent::DeviceFound {
@@ -163,7 +199,10 @@ impl DeviceCommunicationManagerBuilder for LovenseConnectServiceCommunicationMan
 
   fn finish(mut self) -> Box<dyn DeviceCommunicationManager> {
     Box::new(LovenseConnectServiceCommunicationManager::new(
-      self.sender.take().unwrap(),
+      self
+        .sender
+        .take()
+        .expect("We're creating/moving this, so we can take it."),
     ))
   }
 }
@@ -201,8 +240,13 @@ impl DeviceCommunicationManager for LovenseConnectServiceCommunicationManager {
         while is_scanning.load(Ordering::SeqCst) {
           match reqwest::get("https://api.lovense.com/api/lan/getToys").await {
             Ok(res) => {
-              let text = res.text().await.unwrap();
-              let info: LovenseServiceInfo = serde_json::from_str(&text).unwrap();
+              if res.status() != StatusCode::OK {
+                error!("Error contacting Lovense Connect Remote API endpoint. Status returned: {}", res.status());
+                tokio::time::sleep(Duration::from_secs(1)).await;
+                continue;
+              }
+              let text = res.text().await.expect("Should always get json back from service, if we got a response.");
+              let info: LovenseServiceInfo = serde_json::from_str(&text).expect("Should always get json back from service, if we got a response.");
               let mut current_known_hosts = known_hosts.lock().await;
               let new_known_hosts: Vec<String> = info
                 .iter()
@@ -213,7 +257,7 @@ impl DeviceCommunicationManager for LovenseConnectServiceCommunicationManager {
                   // this sometimes fails on DNS resolution. Since we aren't using secure contexts
                   // at the moment, we can just cut out the IP from the domain and use that
                   // directly, which has fixed issues for some users.
-                  let host_parts: Vec<&str> = x.0.split(".").collect();
+                  let host_parts: Vec<&str> = x.0.split('.').collect();
                   let new_http_host = host_parts[0].replace("-", ".");
                   // We set the protocol type here so it'll just filter down, in case we want to move to secure.
                   let host = format!("http://{}:{}", new_http_host, x.1.http_port);
@@ -225,7 +269,7 @@ impl DeviceCommunicationManager for LovenseConnectServiceCommunicationManager {
               if current_known_hosts.len() != new_known_hosts.len()
                 || !current_known_hosts
                   .iter()
-                  .all(|item| new_known_hosts.contains(&item))
+                  .all(|item| new_known_hosts.contains(item))
               {
                 *current_known_hosts = new_known_hosts.iter().map(|x| (*x).clone()).collect();
               }
@@ -243,8 +287,7 @@ impl DeviceCommunicationManager for LovenseConnectServiceCommunicationManager {
                 info!("Lovense Connect Server API query returned: {}", text);
                 async_manager::spawn(async move {
                   service_fut.await;
-                })
-                .unwrap();
+                });
                 break;
               }
             }
@@ -255,8 +298,7 @@ impl DeviceCommunicationManager for LovenseConnectServiceCommunicationManager {
         debug!("Stopping scanning");
       }
       .instrument(info_span!("Lovense Connect Service Scanner")),
-    )
-    .unwrap();
+    );
     Box::pin(async move { Ok(()) })
   }
 
