@@ -6,8 +6,10 @@ pub mod lovense_serial_dongle_comm_manager;
 
 pub use lovense_dongle_device_impl::{LovenseDongleDeviceImpl, LovenseDongleDeviceImplCreator};
 pub use lovense_hid_dongle_comm_manager::{
-  LovenseHIDDongleCommunicationManager, LovenseHIDDongleCommunicationManagerBuilder,
+  LovenseHIDDongleCommunicationManager,
+  LovenseHIDDongleCommunicationManagerBuilder,
 };
 pub use lovense_serial_dongle_comm_manager::{
-  LovenseSerialDongleCommunicationManager, LovenseSerialDongleCommunicationManagerBuilder,
+  LovenseSerialDongleCommunicationManager,
+  LovenseSerialDongleCommunicationManagerBuilder,
 };
