@@ -2,5 +2,6 @@ mod xinput_device_comm_manager;
 mod xinput_device_impl;
 
 pub use xinput_device_comm_manager::{
-  XInputDeviceCommunicationManager, XInputDeviceCommunicationManagerBuilder,
+  XInputDeviceCommunicationManager,
+  XInputDeviceCommunicationManagerBuilder,
 };
