@@ -3,7 +3,9 @@ use crate::{
   core::ButtplugResultFuture,
   device::ButtplugDeviceEvent,
   server::comm_managers::{
-    DeviceCommunicationEvent, DeviceCommunicationManager, DeviceCommunicationManagerBuilder,
+    DeviceCommunicationEvent,
+    DeviceCommunicationManager,
+    DeviceCommunicationManagerBuilder,
   },
   util::async_manager,
 };
@@ -48,7 +50,8 @@ async fn check_gamepad_connectivity(
   sender: Option<broadcast::Sender<ButtplugDeviceEvent>>,
 ) {
   check_running.store(true, Ordering::SeqCst);
-  let handle = rusty_xinput::XInputHandle::load_default().unwrap();
+  let handle = rusty_xinput::XInputHandle::load_default()
+    .expect("Always loads in windows, this shouldn't run elsewhere.");
   loop {
     let gamepads = connected_gamepads.load(Ordering::SeqCst);
     if gamepads == 0 {
@@ -70,11 +73,9 @@ async fn check_gamepad_connectivity(
         let new_connected_gamepads = gamepads & !(1 << *index as u8);
         connected_gamepads.store(new_connected_gamepads, Ordering::SeqCst);
         if let Some(send) = &sender {
-          // This should always succeed, as it'll relay up to the device manager,
-          // and that's what owns us.
           send
             .send(ButtplugDeviceEvent::Removed(create_address(*index)))
-            .unwrap();
+            .expect("Infallible, device manager listening or this doesn't exist.");
         }
         // If we're out of gamepads to track, return immediately.
         if new_connected_gamepads == 0 {
@@ -99,8 +100,7 @@ impl XInputConnectionTracker {
       let check_running = self.check_running.clone();
       async_manager::spawn(async move {
         check_gamepad_connectivity(connected_gamepads, check_running, None).await;
-      })
-      .unwrap();
+      });
     }
   }
 
@@ -118,8 +118,7 @@ impl XInputConnectionTracker {
       let check_running = self.check_running.clone();
       async_manager::spawn(async move {
         check_gamepad_connectivity(connected_gamepads, check_running, Some(sender)).await;
-      })
-      .unwrap();
+      });
     }
   }
 
@@ -141,7 +140,7 @@ impl DeviceCommunicationManagerBuilder for XInputDeviceCommunicationManagerBuild
 
   fn finish(mut self) -> Box<dyn DeviceCommunicationManager> {
     Box::new(XInputDeviceCommunicationManager::new(
-      self.sender.take().unwrap(),
+      self.sender.take().expect("We own it, we'll take it."),
     ))
   }
 }
@@ -173,7 +172,8 @@ impl DeviceCommunicationManager for XInputDeviceCommunicationManager {
     let scanning_notifier = self.scanning_notifier.clone();
     let connected_gamepads = self.connected_gamepads.clone();
     async_manager::spawn(async move {
-      let handle = rusty_xinput::XInputHandle::load_default().unwrap();
+      let handle = rusty_xinput::XInputHandle::load_default()
+        .expect("Always loads in windows, this shouldn't run elsewhere.");
       let mut stop = false;
       while !stop {
         for i in &[
@@ -219,8 +219,7 @@ impl DeviceCommunicationManager for XInputDeviceCommunicationManager {
           }
         }
       }
-    })
-    .unwrap();
+    });
     Box::pin(future::ready(Ok(())))
   }
 
