@@ -10,7 +10,9 @@
 
 use super::{
   comm_managers::{
-    DeviceCommunicationEvent, DeviceCommunicationManager, DeviceCommunicationManagerBuilder,
+    DeviceCommunicationEvent,
+    DeviceCommunicationManager,
+    DeviceCommunicationManagerBuilder,
   },
   device_manager_event_loop::DeviceManagerEventLoop,
   ping_timer::PingTimer,
@@ -20,39 +22,71 @@ use crate::{
   core::{
     errors::{ButtplugDeviceError, ButtplugMessageError, ButtplugUnknownError},
     messages::{
-      self, ButtplugClientMessage, ButtplugDeviceCommandMessageUnion,
-      ButtplugDeviceManagerMessageUnion, ButtplugDeviceMessage, ButtplugMessage,
-      ButtplugServerMessage, DeviceList, DeviceMessageInfo,
+      self,
+      ButtplugClientMessage,
+      ButtplugDeviceCommandMessageUnion,
+      ButtplugDeviceManagerMessageUnion,
+      ButtplugDeviceMessage,
+      ButtplugMessage,
+      ButtplugServerMessage,
+      DeviceList,
+      DeviceMessageInfo,
     },
   },
   device::{
-    configuration_manager::{DeviceConfigurationManager, ProtocolDefinition}, protocol::ButtplugProtocol, ButtplugDevice,
+    configuration_manager::{DeviceConfigurationManager, ProtocolDefinition},
+    protocol::ButtplugProtocol,
+    ButtplugDevice,
   },
   server::ButtplugServerResultFuture,
   util::async_manager,
 };
-use dashmap::{DashMap, DashSet};
+use dashmap::DashMap;
 use futures::future;
+use getset::{Getters, Setters};
+use serde::{Deserialize, Serialize};
 use std::{
   convert::TryFrom,
   sync::{atomic::Ordering, Arc},
 };
 use tokio::sync::{broadcast, mpsc};
 
+#[derive(Serialize, Deserialize, Debug, Getters, Setters, Default, Clone, PartialEq)]
+#[getset(get = "pub", set = "pub")]
+pub struct DeviceUserConfig {
+  #[serde(skip_serializing_if = "Option::is_none")]
+  #[serde(default)]
+  #[serde(rename = "display-name")]
+  display_name: Option<String>,
+  #[serde(skip_serializing_if = "Option::is_none")]
+  #[serde(default)]
+  allow: Option<bool>,
+  #[serde(skip_serializing_if = "Option::is_none")]
+  #[serde(default)]
+  deny: Option<bool>,
+}
+
+#[derive(Debug)]
+pub struct DeviceInfo {
+  pub address: String,
+  pub display_name: Option<String>,
+}
+
 pub struct DeviceManager {
   // This uses a map to make sure we don't have 2 comm managers of the same type
   // register. Also means we can do lockless access since it's a Dashmap.
   comm_managers: Arc<DashMap<String, Box<dyn DeviceCommunicationManager>>>,
   devices: Arc<DashMap<u32, Arc<ButtplugDevice>>>,
-  device_allow_list: Arc<DashSet<String>>,
-  device_deny_list: Arc<DashSet<String>>,
+  device_user_config: Arc<DashMap<String, DeviceUserConfig>>,
   device_event_sender: mpsc::Sender<DeviceCommunicationEvent>,
   config: Arc<DeviceConfigurationManager>,
 }
 
-unsafe impl Send for DeviceManager {}
+unsafe impl Send for DeviceManager {
+}
 
-unsafe impl Sync for DeviceManager {}
+unsafe impl Sync for DeviceManager {
+}
 
 impl DeviceManager {
   pub fn new(
@@ -63,26 +97,22 @@ impl DeviceManager {
     let config = Arc::new(DeviceConfigurationManager::new(allow_raw_messages));
     let devices = Arc::new(DashMap::new());
     let (device_event_sender, device_event_receiver) = mpsc::channel(256);
-    let device_allow_list = Arc::new(DashSet::new());
-    let device_deny_list = Arc::new(DashSet::new());
+    let device_user_config = Arc::new(DashMap::new());
     let mut event_loop = DeviceManagerEventLoop::new(
       config.clone(),
       output_sender,
       devices.clone(),
-      device_allow_list.clone(),
-      device_deny_list.clone(),
+      device_user_config.clone(),
       ping_timer,
       device_event_receiver,
     );
     async_manager::spawn(async move {
       event_loop.run().await;
-    })
-    .unwrap();
+    });
     Self {
       device_event_sender,
       devices,
-      device_allow_list,
-      device_deny_list,
+      device_user_config,
       comm_managers: Arc::new(DashMap::new()),
       config,
     }
@@ -249,9 +279,8 @@ impl DeviceManager {
       sender
         .send(DeviceCommunicationEvent::DeviceManagerAdded(status))
         .await
-        .unwrap();
-    })
-    .unwrap();
+        .expect("We should always have an event loop for this to go to.");
+    });
     self.comm_managers.insert(mgr.name().to_owned(), mgr);
     Ok(())
   }
@@ -290,27 +319,31 @@ impl DeviceManager {
   }
 
   pub fn remove_protocol_definition(&self, name: &str) {
-    self.config.remove_protocol_definition(name);    
+    self.config.remove_protocol_definition(name);
   }
 
-  pub fn add_allowed_device(&self, address: &str) {
-    info!("Adding device address {} to allowed devices list.", address);
-    self.device_allow_list.insert(address.to_owned());
+  pub fn add_device_user_config(&self, address: &str, config: DeviceUserConfig) {
+    info!(
+      "Adding device user config for address {} with values {:?}.",
+      address, config
+    );
+    self.device_user_config.insert(address.to_owned(), config);
   }
 
-  pub fn add_denied_device(&self, address: &str) {
-    info!("Adding device address {} to denied devices list.", address);
-    self.device_deny_list.insert(address.to_owned());
+  pub fn remove_device_user_config(&self, address: &str) {
+    info!("Removing device user config for address {}.", address);
+    self.device_user_config.remove(address);
   }
 
-  pub fn remove_allowed_device(&self, address: &str) {
-    info!("Removing device address {} from allowed devices list.", address);
-    self.device_allow_list.remove(address);
-  }
-
-  pub fn remove_denied_device(&self, address: &str) {
-    info!("Removing device address {} from denied devices list.", address);
-    self.device_deny_list.remove(address);
+  pub fn device_info(&self, index: u32) -> Result<DeviceInfo, ButtplugDeviceError> {
+    if let Some(device) = self.devices.get(&index) {
+      Ok(DeviceInfo {
+        address: device.value().address().to_owned(),
+        display_name: device.value().display_name(),
+      })
+    } else {
+      Err(ButtplugDeviceError::DeviceNotAvailable(index))
+    }
   }
 }
 
