@@ -19,12 +19,22 @@ use crate::{
   core::{
     errors::*,
     messages::{
-      self, ButtplugClientMessage, ButtplugDeviceCommandMessageUnion,
-      ButtplugDeviceManagerMessageUnion, ButtplugMessage, ButtplugServerMessage, StopAllDevices,
-      StopScanning, BUTTPLUG_CURRENT_MESSAGE_SPEC_VERSION,
+      self,
+      ButtplugClientMessage,
+      ButtplugDeviceCommandMessageUnion,
+      ButtplugDeviceManagerMessageUnion,
+      ButtplugMessage,
+      ButtplugServerMessage,
+      StopAllDevices,
+      StopScanning,
+      BUTTPLUG_CURRENT_MESSAGE_SPEC_VERSION,
     },
   },
-  util::{async_manager, stream::convert_broadcast_receiver_to_stream, device_configuration::{DEVICE_CONFIGURATION_JSON, load_protocol_config_from_json}},
+  util::{
+    async_manager,
+    device_configuration::{load_protocol_config_from_json, DEVICE_CONFIGURATION_JSON},
+    stream::convert_broadcast_receiver_to_stream,
+  },
 };
 use device_manager::DeviceManager;
 use futures::{
@@ -32,12 +42,9 @@ use futures::{
   Stream,
 };
 use ping_timer::PingTimer;
-use std::{
-  convert::{TryFrom, TryInto},
-  sync::{
-    atomic::{AtomicBool, Ordering},
-    Arc,
-  },
+use std::sync::{
+  atomic::{AtomicBool, Ordering},
+  Arc,
 };
 use thiserror::Error;
 use tokio::sync::broadcast;
@@ -59,7 +66,7 @@ pub enum ButtplugServerError {
 #[derive(Debug, Clone)]
 pub struct ButtplugServerBuilder {
   pub name: String,
-  pub max_ping_time: Option<u64>,
+  pub max_ping_time: Option<u32>,
   pub allow_raw_messages: bool,
   pub device_configuration_json: Option<String>,
   pub user_device_configuration_json: Option<String>,
@@ -83,7 +90,7 @@ impl ButtplugServerBuilder {
     self
   }
 
-  pub fn max_ping_time(&mut self, ping_time: u64) -> &mut Self {
+  pub fn max_ping_time(&mut self, ping_time: u32) -> &mut Self {
     self.max_ping_time = Some(ping_time);
     self
   }
@@ -106,14 +113,14 @@ impl ButtplugServerBuilder {
   pub fn finish(&self) -> Result<ButtplugServer, ButtplugError> {
     // If the user config string exists, parse it.
     let user_config = if let Some(user_device_config) = &self.user_device_configuration_json {
-      Some(load_protocol_config_from_json(&user_device_config)?)
+      Some(load_protocol_config_from_json(user_device_config)?)
     } else {
       None
     };
-    
+
     // If the device config string exists, parse it.
     let device_config = if let Some(main_device_config) = &self.device_configuration_json {
-      let mut main_config = load_protocol_config_from_json(&main_device_config)?;
+      let mut main_config = load_protocol_config_from_json(main_device_config)?;
       if let Some(user_config) = user_config {
         main_config.merge(user_config);
       }
@@ -146,18 +153,17 @@ impl ButtplugServerBuilder {
         };
       }
       .instrument(tracing::info_span!("Buttplug Server Ping Timeout Task")),
-    )
-    .unwrap();
-    let device_manager = DeviceManager::new(
-      send.clone(),
-      ping_timer.clone(),
-      self.allow_raw_messages
     );
+    let device_manager =
+      DeviceManager::new(send.clone(), ping_timer.clone(), self.allow_raw_messages);
 
     if let Some(devices) = device_config {
       for (name, def) in devices.protocols {
         device_manager.add_protocol_definition(&name, def);
       }
+      for (address, user_config) in devices.user_config {
+        device_manager.add_device_user_config(&address, user_config);
+      }
     }
 
     let server = ButtplugServer {
@@ -181,7 +187,7 @@ impl ButtplugServerBuilder {
 /// Represents a ButtplugServer.
 pub struct ButtplugServer {
   server_name: String,
-  max_ping_time: u64,
+  max_ping_time: u32,
   device_manager: DeviceManager,
   ping_timer: Arc<PingTimer>,
   connected: Arc<AtomicBool>,
@@ -191,7 +197,9 @@ pub struct ButtplugServer {
 impl Default for ButtplugServer {
   fn default() -> Self {
     // We can unwrap here because if default init fails, so will pretty much every test.
-    ButtplugServerBuilder::default().finish().unwrap()
+    ButtplugServerBuilder::default()
+      .finish()
+      .expect("Default is infallible")
   }
 }
 
@@ -321,7 +329,7 @@ impl ButtplugServer {
     let out_msg = messages::ServerInfo::new(
       &self.server_name,
       BUTTPLUG_CURRENT_MESSAGE_SPEC_VERSION,
-      self.max_ping_time.try_into().unwrap(),
+      self.max_ping_time,
     );
     let connected = self.connected.clone();
     Box::pin(async move {
