@@ -29,8 +29,7 @@ impl std::io::Write for ChannelWriter {
       // Ignore errors on dropped channels here. We can't really do a ton about
       // them.
       let _ = sender.send(send_buf.to_vec()).await;
-    })
-    .unwrap();
+    });
     Ok(len)
   }
 
@@ -39,7 +38,7 @@ impl std::io::Write for ChannelWriter {
   }
 }
 
-impl MakeWriter for ChannelWriter {
+impl MakeWriter<'_> for ChannelWriter {
   type Writer = ChannelWriter;
   fn make_writer(&self) -> Self::Writer {
     ChannelWriter::new(self.log_sender.clone())
