@@ -1,7 +1,10 @@
 mod util;
 use buttplug::{
   client::{
-    ButtplugClient, ButtplugClientDeviceEvent, ButtplugClientError, ButtplugClientEvent,
+    ButtplugClient,
+    ButtplugClientDeviceEvent,
+    ButtplugClientError,
+    ButtplugClientEvent,
     VibrateCommand,
   },
   connector::ButtplugInProcessClientConnector,
@@ -25,12 +28,22 @@ fn test_client_device_connected_status() {
     let connector = ButtplugInProcessClientConnector::default();
     let builder = TestDeviceCommunicationManagerBuilder::default();
     let helper = builder.helper();
-    connector.server_ref().device_manager().add_comm_manager(builder).unwrap();
+    connector
+      .server_ref()
+      .device_manager()
+      .add_comm_manager(builder)
+      .expect("Test, assuming infallible.");
     let device = helper.add_ble_device("Massage Demo").await;
     assert!(!client.connected());
-    client.connect(connector).await.unwrap();
+    client
+      .connect(connector)
+      .await
+      .expect("Test, assuming infallible.");
     assert!(client.connected());
-    client.start_scanning().await.unwrap();
+    client
+      .start_scanning()
+      .await
+      .expect("Test, assuming infallible.");
     let mut client_device = None;
     while let Some(msg) = event_stream.next().await {
       if let ButtplugClientEvent::DeviceAdded(da) = msg {
@@ -38,17 +51,23 @@ fn test_client_device_connected_status() {
         break;
       }
     }
-    let test_device = client_device.unwrap();
+    let test_device = client_device.expect("Test, assuming infallible.");
     let mut device_event_stream = test_device.event_stream();
     assert!(test_device.connected());
-    device.disconnect().await.unwrap();
+    device
+      .disconnect()
+      .await
+      .expect("Test, assuming infallible.");
     while let Some(msg) = device_event_stream.next().await {
       if let ButtplugClientDeviceEvent::DeviceRemoved = msg {
         assert!(!test_device.connected());
         break;
       }
     }
-    client.disconnect().await.unwrap();
+    client
+      .disconnect()
+      .await
+      .expect("Test, assuming infallible.");
     assert!(!client.connected());
   });
 }
@@ -62,12 +81,22 @@ fn test_client_device_client_disconnected_status() {
     let connector = ButtplugInProcessClientConnector::default();
     let builder = TestDeviceCommunicationManagerBuilder::default();
     let helper = builder.helper();
-    connector.server_ref().device_manager().add_comm_manager(builder).unwrap();
+    connector
+      .server_ref()
+      .device_manager()
+      .add_comm_manager(builder)
+      .expect("Test, assuming infallible.");
     let _ = helper.add_ble_device("Massage Demo").await;
     assert!(!client.connected());
-    client.connect(connector).await.unwrap();
+    client
+      .connect(connector)
+      .await
+      .expect("Test, assuming infallible.");
     assert!(client.connected());
-    client.start_scanning().await.unwrap();
+    client
+      .start_scanning()
+      .await
+      .expect("Test, assuming infallible.");
     let mut client_device = None;
     while let Some(msg) = event_stream.next().await {
       if let ButtplugClientEvent::DeviceAdded(da) = msg {
@@ -75,10 +104,13 @@ fn test_client_device_client_disconnected_status() {
         break;
       }
     }
-    let test_device = client_device.unwrap();
+    let test_device = client_device.expect("Test, assuming infallible.");
     let mut device_event_stream = test_device.event_stream();
     assert!(test_device.connected());
-    client.disconnect().await.unwrap();
+    client
+      .disconnect()
+      .await
+      .expect("Test, assuming infallible.");
     while let Some(msg) = event_stream.next().await {
       if let ButtplugClientEvent::ServerDisconnect = msg {
         assert!(!client.connected());
@@ -102,16 +134,32 @@ fn test_client_device_connected_no_event_listener() {
     let connector = ButtplugInProcessClientConnector::default();
     let builder = TestDeviceCommunicationManagerBuilder::default();
     let helper = builder.helper();
-    connector.server_ref().device_manager().add_comm_manager(builder).unwrap();
+    connector
+      .server_ref()
+      .device_manager()
+      .add_comm_manager(builder)
+      .expect("Test, assuming infallible.");
     let device = helper.add_ble_device("Massage Demo").await;
     assert!(!client.connected());
-    client.connect(connector).await.unwrap();
+    client
+      .connect(connector)
+      .await
+      .expect("Test, assuming infallible.");
     assert!(client.connected());
-    client.start_scanning().await.unwrap();
+    client
+      .start_scanning()
+      .await
+      .expect("Test, assuming infallible.");
     Delay::new(Duration::from_millis(100)).await;
-    device.disconnect().await.unwrap();
+    device
+      .disconnect()
+      .await
+      .expect("Test, assuming infallible.");
     Delay::new(Duration::from_millis(100)).await;
-    client.disconnect().await.unwrap();
+    client
+      .disconnect()
+      .await
+      .expect("Test, assuming infallible.");
     assert!(!client.connected());
     Delay::new(Duration::from_millis(100)).await;
   });
@@ -126,12 +174,22 @@ fn test_client_device_invalid_command() {
     let connector = ButtplugInProcessClientConnector::default();
     let builder = TestDeviceCommunicationManagerBuilder::default();
     let helper = builder.helper();
-    connector.server_ref().device_manager().add_comm_manager(builder).unwrap();
+    connector
+      .server_ref()
+      .device_manager()
+      .add_comm_manager(builder)
+      .expect("Test, assuming infallible.");
     let _ = helper.add_ble_device("Massage Demo").await;
     assert!(!client.connected());
-    client.connect(connector).await.unwrap();
+    client
+      .connect(connector)
+      .await
+      .expect("Test, assuming infallible.");
     assert!(client.connected());
-    client.start_scanning().await.unwrap();
+    client
+      .start_scanning()
+      .await
+      .expect("Test, assuming infallible.");
     let mut client_device = None;
     while let Some(msg) = event_stream.next().await {
       if let ButtplugClientEvent::DeviceAdded(da) = msg {
@@ -139,7 +197,7 @@ fn test_client_device_invalid_command() {
         break;
       }
     }
-    let test_device = client_device.unwrap();
+    let test_device = client_device.expect("Test, assuming infallible.");
     assert!(matches!(
       test_device
         .vibrate(VibrateCommand::Speed(2.0))
@@ -191,15 +249,24 @@ fn test_client_repeated_deviceadded_message() {
         .send_client_incoming(device_added.clone().into())
         .await;
       helper_clone.send_client_incoming(device_added.into()).await;
-    })
-    .unwrap();
-    helper.client().start_scanning().await.unwrap();
+    });
+    helper
+      .client()
+      .start_scanning()
+      .await
+      .expect("Test, assuming infallible.");
     assert!(matches!(
-      event_stream.next().await.unwrap(),
+      event_stream
+        .next()
+        .await
+        .expect("Test, assuming infallible."),
       ButtplugClientEvent::DeviceAdded(..)
     ));
     assert!(matches!(
-      event_stream.next().await.unwrap(),
+      event_stream
+        .next()
+        .await
+        .expect("Test, assuming infallible."),
       ButtplugClientEvent::Error(..)
     ));
   });
@@ -230,19 +297,31 @@ fn test_client_repeated_deviceremoved_message() {
       helper_clone
         .send_client_incoming(device_removed.into())
         .await;
-    })
-    .unwrap();
-    helper.client().start_scanning().await.unwrap();
+    });
+    helper
+      .client()
+      .start_scanning()
+      .await
+      .expect("Test, assuming infallible.");
     assert!(matches!(
-      event_stream.next().await.unwrap(),
+      event_stream
+        .next()
+        .await
+        .expect("Test, assuming infallible."),
       ButtplugClientEvent::DeviceAdded(..)
     ));
     assert!(matches!(
-      event_stream.next().await.unwrap(),
+      event_stream
+        .next()
+        .await
+        .expect("Test, assuming infallible."),
       ButtplugClientEvent::DeviceRemoved(..)
     ));
     assert!(matches!(
-      event_stream.next().await.unwrap(),
+      event_stream
+        .next()
+        .await
+        .expect("Test, assuming infallible."),
       ButtplugClientEvent::Error(..)
     ));
   });
